Stan Math Library: stan/math/rev/mat/fun/mdivide_left_tri.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
mdivide_left_tri.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/fun/typedefs.hpp>`
`#include <stan/math/prim/mat/err/check_multiplicable.hpp>`
`#include <stan/math/prim/mat/err/check_square.hpp>`
`#include <stan/math/rev/core.hpp>`
`#include <stan/math/rev/mat/fun/typedefs.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<int TriView, int R1, int C1, int R2, int C2>
Eigen::Matrix< var, R1, C2 > | stan::math::mdivide_left_tri (const Eigen::Matrix< var, R1, C1 > &A, const Eigen::Matrix< var, R2, C2 > &b)
template<int TriView, int R1, int C1, int R2, int C2>
Eigen::Matrix< var, R1, C2 > | stan::math::mdivide_left_tri (const Eigen::Matrix< double, R1, C1 > &A, const Eigen::Matrix< var, R2, C2 > &b)
template<int TriView, int R1, int C1, int R2, int C2>
Eigen::Matrix< var, R1, C2 > | stan::math::mdivide_left_tri (const Eigen::Matrix< var, R1, C1 > &A, const Eigen::Matrix< double, R2, C2 > &b)

## Variable Documentation

vari** _variRefA

Definition at line 23 of file mdivide_left_tri.hpp.

vari** _variRefB

Definition at line 24 of file mdivide_left_tri.hpp.

vari** _variRefC

Definition at line 25 of file mdivide_left_tri.hpp.

double* A_

Definition at line 21 of file mdivide_left_tri.hpp.

double* C_

Definition at line 22 of file mdivide_left_tri.hpp.

int M_

Definition at line 19 of file mdivide_left_tri.hpp.

int N_

Definition at line 20 of file mdivide_left_tri.hpp.

[ Stan Home Page ] © 2011–2016, Stan Development Team.